==> qiho-center-api-2.11.32-20230828.030942-3-sources.jar: com/qiho/center/api/params/OrderPageParams.java <==
package com.qiho.center.api.params;

import com.qiho.center.api.enums.RemoteInvokeEnum;
import com.qiho.center.api.enums.flag.FlagAfterSaleStatusEnum;

import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * Created by liuyao on 2017/6/2.
 * 全部订单检索分页封装
 */
public class OrderPageParams extends PageQueryParams{

    private String orderId;

    private Long itemId;
    private List<Long> itemIdList;
    private String itemName;
    private String itemNo;
    private String skuNo;

    private String postId;
    private String consumerName;
    private String mobile;
    private Long merchantId;
    private List<Long> merchantIdList;

    private Date startTime;
    private Date endTime;
    private String orderStatus;

    private Set<String> orderStatusSet;

    private String delivery;
    private String channelId;
    private String countChannelId;
    private String tuiaId;
    private String ip;

    private String orderProcessWay;
    private Date processTime;

    /** RPC调用来源 */
    private RemoteInvokeEnum remoteInvoke;

    private String scrollId;

    /** 推啊活动用户ID */
    private String tuiaCid;

    /**
     * 当前参数查询关联的AeID
     */
    private Long relevantAeId;

    private Integer cancelOperateType;

    /**
     * 售后订单状态
     * {@link FlagAfterSaleStatusEnum}
     */
    private Integer flagAfterSaleStatus;

    /**
     * 支付方式
     * {@link com.qiho.center.api.enums.PayTypeEnum}
     */
    private String payType;

    //资金状态,TO_PAY-待付款/SUCCESS-付款成功/FAILED-付款失败
    private String  fundStatus;

    public String getScrollId() {
        return scrollId;
    }

    public void setScrollId(String scrollId) {
        this.scrollId = scrollId;
    }

    public RemoteInvokeEnum getRemoteInvoke() {
        return remoteInvoke;
    }

    public void setRemoteInvoke(RemoteInvokeEnum remoteInvoke) {
        this.remoteInvoke = remoteInvoke;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getSkuNo() {
        return skuNo;
    }

    public void setSkuNo(String skuNo) {
        this.skuNo = skuNo;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }

    public String getChannelId() {
        return channelId;
    }

    public void setChannelId(String channelId) {
        this.channelId = channelId;
    }

    public String getCountChannelId() {
        return countChannelId;
    }

    public void setCountChannelId(String countChannelId) {
        this.countChannelId = countChannelId;
    }

    public String getTuiaId() {
        return tuiaId;
    }

    public void setTuiaId(String tuiaId) {
        this.tuiaId = tuiaId;
    }

    public String getOrderProcessWay() {
        return orderProcessWay;
    }

    public void setOrderProcessWay(String orderProcessWay) {
        this.orderProcessWay = orderProcessWay;
    }

    public Date getProcessTime() {
        return processTime;
    }

    public void setProcessTime(Date processTime) {
        this.processTime = processTime;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getTuiaCid() {
        return tuiaCid;
    }

    public void setTuiaCid(String tuiaCid) {
        this.tuiaCid = tuiaCid;
    }

    public Long getRelevantAeId() {
        return relevantAeId;
    }

    public void setRelevantAeId(Long relevantAeId) {
        this.relevantAeId = relevantAeId;
    }

    public List<Long> getMerchantIdList() {
        return merchantIdList;
    }

    public void setMerchantIdList(List<Long> merchantIdList) {
        this.merchantIdList = merchantIdList;
    }

    public Set<String> getOrderStatusSet() {
        return orderStatusSet;
    }

    public void setOrderStatusSet(Set<String> orderStatusSet) {
        this.orderStatusSet = orderStatusSet;
    }

    public Integer getCancelOperateType() {
        return cancelOperateType;
    }

    public void setCancelOperateType(Integer cancelOperateType) {
        this.cancelOperateType = cancelOperateType;
    }

    public Integer getFlagAfterSaleStatus() {
        return flagAfterSaleStatus;
    }

    public void setFlagAfterSaleStatus(Integer flagAfterSaleStatus) {
        this.flagAfterSaleStatus = flagAfterSaleStatus;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getFundStatus() {
        return fundStatus;
    }

    public void setFundStatus(String fundStatus) {
        this.fundStatus = fundStatus;
    }

    public List<Long> getItemIdList() {
        return itemIdList;
    }

    public void setItemIdList(List<Long> itemIdList) {
        this.itemIdList = itemIdList;
    }
}

==> qiho-center-api-2.11.65-sources.jar: com/qiho/center/api/params/OrderPageParams.java <==
package com.qiho.center.api.params;

import com.qiho.center.api.enums.RemoteInvokeEnum;
import com.qiho.center.api.enums.flag.FlagAfterSaleStatusEnum;

import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * Created by liuyao on 2017/6/2.
 * 全部订单检索分页封装
 */
public class OrderPageParams extends PageQueryParams{

    private String orderId;

    private Long itemId;
    private List<Long> itemIdList;
    private String itemName;
    private String itemNo;
    private String skuNo;

    private String postId;
    private String consumerName;
    private String mobile;
    private Long merchantId;
    private List<Long> merchantIdList;
    private List<Long> notInMerchantIdList;

    private Date startTime;
    private Date endTime;
    private String orderStatus;

    private Set<String> orderStatusSet;

    private String delivery;
    private String channelId;
    private String countChannelId;
    private String tuiaId;
    private String ip;

    private String orderProcessWay;
    private Date processTime;

    /** RPC调用来源 */
    private RemoteInvokeEnum remoteInvoke;

    private String scrollId;

    /** 推啊活动用户ID */
    private String tuiaCid;

    /**
     * 当前参数查询关联的AeID
     */
    private Long relevantAeId;

    private Integer cancelOperateType;

    /**
     * 售后订单状态
     * {@link FlagAfterSaleStatusEnum}
     */
    private Integer flagAfterSaleStatus;

    /**
     * 支付方式
     * {@link com.qiho.center.api.enums.PayTypeEnum}
     */
    private String payType;

    //资金状态,TO_PAY-待付款/SUCCESS-付款成功/FAILED-付款失败
    private String  fundStatus;

    private Integer randomCount;

    /**
     * 生成方式，0-手动 1-自动
     */
    private Integer generateType;

    public Integer getRandomCount() {
        return randomCount;
    }

    public void setRandomCount(Integer randomCount) {
        this.randomCount = randomCount;
    }

    public List<Long> getNotInMerchantIdList() {
        return notInMerchantIdList;
    }

    public void setNotInMerchantIdList(List<Long> notInMerchantIdList) {
        this.notInMerchantIdList = notInMerchantIdList;
    }

    public String getScrollId() {
        return scrollId;
    }

    public void setScrollId(String scrollId) {
        this.scrollId = scrollId;
    }

    public RemoteInvokeEnum getRemoteInvoke() {
        return remoteInvoke;
    }

    public void setRemoteInvoke(RemoteInvokeEnum remoteInvoke) {
        this.remoteInvoke = remoteInvoke;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getSkuNo() {
        return skuNo;
    }

    public void setSkuNo(String skuNo) {
        this.skuNo = skuNo;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }

    public String getChannelId() {
        return channelId;
    }

    public void setChannelId(String channelId) {
        this.channelId = channelId;
    }

    public String getCountChannelId() {
        return countChannelId;
    }

    public void setCountChannelId(String countChannelId) {
        this.countChannelId = countChannelId;
    }

    public String getTuiaId() {
        return tuiaId;
    }

    public void setTuiaId(String tuiaId) {
        this.tuiaId = tuiaId;
    }

    public String getOrderProcessWay() {
        return orderProcessWay;
    }

    public void setOrderProcessWay(String orderProcessWay) {
        this.orderProcessWay = orderProcessWay;
    }

    public Date getProcessTime() {
        return processTime;
    }

    public void setProcessTime(Date processTime) {
        this.processTime = processTime;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getTuiaCid() {
        return tuiaCid;
    }

    public void setTuiaCid(String tuiaCid) {
        this.tuiaCid = tuiaCid;
    }

    public Long getRelevantAeId() {
        return relevantAeId;
    }

    public void setRelevantAeId(Long relevantAeId) {
        this.relevantAeId = relevantAeId;
    }

    public List<Long> getMerchantIdList() {
        return merchantIdList;
    }

    public void setMerchantIdList(List<Long> merchantIdList) {
        this.merchantIdList = merchantIdList;
    }

    public Set<String> getOrderStatusSet() {
        return orderStatusSet;
    }

    public void setOrderStatusSet(Set<String> orderStatusSet) {
        this.orderStatusSet = orderStatusSet;
    }

    public Integer getCancelOperateType() {
        return cancelOperateType;
    }

    public void setCancelOperateType(Integer cancelOperateType) {
        this.cancelOperateType = cancelOperateType;
    }

    public Integer getFlagAfterSaleStatus() {
        return flagAfterSaleStatus;
    }

    public void setFlagAfterSaleStatus(Integer flagAfterSaleStatus) {
        this.flagAfterSaleStatus = flagAfterSaleStatus;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public String getFundStatus() {
        return fundStatus;
    }

    public void setFundStatus(String fundStatus) {
        this.fundStatus = fundStatus;
    }

    public List<Long> getItemIdList() {
        return itemIdList;
    }

    public void setItemIdList(List<Long> itemIdList) {
        this.itemIdList = itemIdList;
    }

    public Integer getGenerateType() {
        return generateType;
    }

    public void setGenerateType(Integer generateType) {
        this.generateType = generateType;
    }
}
